==> haskell-wai-handler-launch-3.0.3.1-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-handler-launch
version:              3.0.3.1
visibility:           public
id:                   wai-handler-launch-3.0.3.1-Iec8ZjjubEQEJBv3WxJ1qU
key:                  wai-handler-launch-3.0.3.1-Iec8ZjjubEQEJBv3WxJ1qU
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
synopsis:             Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.

category:             Web
abi:                  1c808a1b0cffc5b4cf0fddf4a5fb89ca
exposed:              True
exposed-modules:      Network.Wai.Handler.Launch
import-dirs:          /usr/lib/ghc-8.10.1/site-local/wai-handler-launch-3.0.3.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/wai-handler-launch-3.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.1/wai-handler-launch-3.0.3.1

hs-libraries:         HSwai-handler-launch-3.0.3.1-Iec8ZjjubEQEJBv3WxJ1qU
depends:
    async-2.2.2-5YJmnoR0sNS1wEXdEae9tM base-4.14.0.0
    bytestring-0.10.10.0 http-types-0.12.3-8jqx3L5w5h7IiSPI9SIzwy
    process-1.6.8.2 streaming-commons-0.2.1.2-EVRk2CyuVPI8SBNZfCNqAz
    transformers-0.5.6.2 wai-3.2.2.1-6t3C2NJF0ZM9O27Q2jm0I0
    warp-3.3.10-C9JxeUPENzjD1tgZO5kXiU

haddock-interfaces:
    /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock

haddock-html:         /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-handler-launch-3.0.3.1-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-handler-launch
version:              3.0.3.1
visibility:           public
id:                   wai-handler-launch-3.0.3.1-IuS8OmdcFsKKKaJEIAZ7GI
key:                  wai-handler-launch-3.0.3.1-IuS8OmdcFsKKKaJEIAZ7GI
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
synopsis:             Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.

category:             Web
abi:                  802fb2b26f0b4ce2f0c39edf3b9829d6
exposed:              True
exposed-modules:      Network.Wai.Handler.Launch
import-dirs:          /usr/lib/ghc-8.10.1/site-local/wai-handler-launch-3.0.3.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/wai-handler-launch-3.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.1/wai-handler-launch-3.0.3.1

hs-libraries:         HSwai-handler-launch-3.0.3.1-IuS8OmdcFsKKKaJEIAZ7GI
depends:
    async-2.2.2-Bj86P845FxLFtoqnXRki4A base-4.14.0.0
    bytestring-0.10.10.0 http-types-0.12.3-1kde9KJAuu38Zmp5WnQ1fU
    process-1.6.8.2 streaming-commons-0.2.1.2-DJOCMER4eXcCrNPyw1vpMS
    transformers-0.5.6.2 wai-3.2.2.1-3MZN0hsjN1f5dgCtoZeKBL
    warp-3.3.12-IjFbPRphoKY3pNuI4TWuPK

haddock-interfaces:
    /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock

haddock-html:         /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
